========
Colophon
========

Why Yorkshire?
==============

Monty Python's "Four Yorkshiremen" sketch is perhaps the best embodiment of the spirit of this project:

.. raw:: html

    <iframe width="690" height="500" src="https://www.youtube.com/embed/ue7wM0QC5LE" frameborder="0" gesture="media" allow="encrypted-media" allowfullscreen></iframe>

That is - a bunch of (ahem... old) people, sitting around, pining for "the good old days", lamenting how kids these days don't know how good they've got it.

